@@ -14,7 +14,7 @@ class ConnectionTimeOut(Error):
 class CommandFailedError(Error):
     """Exception raised when server occures an error"""
 
-    def __init__(self, message):
+    def __init__(self, message="Failed while executing the command"):
         self.expression = exc_info()[2]
         self.message = message  
     
@@ -28,6 +28,6 @@ class NotValidCGPStringError(Error):
 class FailedLogin(Error):
     """Exception raised when username or password does not match"""
 
-    def __init__(self, message):
+    def __init__(self, message='Wrong username or password'):
         self.expression = exc_info()[2]
         self.message = message
\ No newline at end of file
